==> nextcloud-29.0.5.tgz: nextcloud/apps/logreader/l10n/pl.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Dziennik zdarzeń",
    "Errors in the log" : "Błędy w logu",
    "No errors in the logs since %s" : "Żadnych błędów w logach od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n błąd w logach od %s","%n błędy w logach od %s","%n błędów w logach od %s","%n błędów w logach od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n ostrzeżenie w logach od %s","%n ostrzeżenia w logach od %s","%n ostrzeżeń w logach od %s","%n ostrzeżeń w logach od %s"],
    "Log Reader" : "Dziennik logów",
    "A log reader for Nextcloud" : "Dziennik logów dla Nextcloud",
    "Log reader for Nextcloud" : "Dziennik logów dla Nextcloud",
    "Log reader" : "Dziennik logów",
    "Open log reader settings" : "Otwórz ustawienia dziennika logów",
    "Log reader settings" : "Ustawienia dziennika logów",
    "Currently the log file {file} is shown" : "Obecnie wyświetlany jest plik dziennika {file}",
    "Show server log" : "Pokaż logi serwera",
    "Live view is disabled" : "Podgląd na żywo jest wyłączony",
    "No log file" : "Brak pliku dziennika",
    "File-based logging must be enabled to access logs from the Web UI." : "Aby uzyskać dostęp do dzienników z internetowego interfejsu użytkownika, należy włączyć rejestrowanie oparte na plikach.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Jeśli uważasz, że to błąd, sprawdź {setting} w swoim {config} i zapoznaj się z instrukcją administracji Nextcloud.",
    "Level" : "Poziom",
    "App" : "Aplikacja",
    "No app in context" : "Brak aplikacji w kontekście",
    "Time" : "Czas",
    "Copy raw entry" : "Kopiuj nieprzetworzony wpis",
    "Copy formatted entry" : "Kopiuj sformatowany wpis",
    "Hide exception details" : "Ukryj szczegóły wyjątku",
    "View exception details" : "Wyświetl szczegóły wyjątku",
    "Raw log entry" : "Nieprzetworzony wpis dziennika",
    "Log entry successfully copied" : "Wpis dziennika został pomyślnie skopiowany",
    "Search log entries" : "Szukaj wpisy dziennika",
    "Caused by {exception}" : "Spowodowane przez {exception}",
    "Line {line}" : "Kolejka {line}",
    "Filter log levels" : "Filtruj poziomy logów",
    "Time format" : "Format czasu",
    "Live view" : "Na żywo",
    "Download/Upload logs" : "Pobierz/prześlij logi",
    "Download logs" : "Pobierz dziennik",
    "Show local log file" : "Pokaż lokalny plik dziennika",
    "Upload local log file to be displayed" : "Wyślij lokalny plik dziennika, który ma zostać wyświetlony",
    "Ctrl" : "Ctrl",
    "Raw data" : "Nieprzetworzone dane",
    "Local time" : "Czas lokalny",
    "UTC time" : "Czas UTC",
    "Relative" : "Pokrewny",
    "Time format used for displaying the timestamp" : "Format czasu używany do wyświetlania znacznika czasu",
    "(Local log files only support the \"raw\" time format)" : "(Lokalne pliki dziennika obsługują tylko \"nieprzetworzony\" format czasu)",
    "Could not change date time format." : "Nie można zmienić formatu daty i godziny.",
    "Polling is disabled because server is not configured to log to file" : "Odpytywanie jest wyłączone, ponieważ serwer nie jest skonfigurowany dla pliku dziennika",
    "Polling (live view)" : "Sonda (podgląd na żywo)",
    "Could not change live view setting." : "Nie można zmienić ustawień podglądu na żywo.",
    "Filter logging levels" : "Filtruj poziomy dziennika",
    "Could not set logging levels to show" : "Nie można ustawić poziomów dziennika do wyświetlenia",
    "Application" : "Aplikacja",
    "Message" : "Komunikat",
    "Log entry actions" : "Akcje z wpisami dziennika",
    "Loading older log entries" : "Ładowanie starszych wpisów dziennika",
    "No older log entries available" : "Brak dostępnych starszych wpisów dziennika",
    "Collapse row" : "Zwiń wiersz",
    "Expand row" : "Rozwiń wiersz",
    "Show details" : "Pokaż szczegóły",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Nie można wczytać wpisów dziennika",
    "Could not fetch new log entries (server unavailable)" : "Nie można pobrać nowych wpisów dziennika (serwer niedostępny)",
    "Could not fetch new entries" : "Nie udało się pobrać nowych wpisów",
    "Could not copy to clipboard, please copy manually:" : "Nie można skopiować do schowka, skopiuj ręcznie:",
    "\tfrom {address} by {user} at {time}\n" : "\tz {address} przez: {user} o {time}\n",
    "line {line}" : "linia {line}",
    "Download / Upload logs" : "Pobierz/prześlij logi"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-29.0.10.tgz: nextcloud/apps/logreader/l10n/pl.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Dziennik zdarzeń",
    "Errors in the log" : "Błędy w logu",
    "No errors in the logs since %s" : "Żadnych błędów w logach od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n błąd w logach od %s","%n błędy w logach od %s","%n błędów w logach od %s","%n błędów w logach od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n ostrzeżenie w logach od %s","%n ostrzeżenia w logach od %s","%n ostrzeżeń w logach od %s","%n ostrzeżeń w logach od %s"],
    "Log Reader" : "Dziennik logów",
    "A log reader for Nextcloud" : "Dziennik logów dla Nextcloud",
    "Log reader for Nextcloud" : "Dziennik logów dla Nextcloud",
    "Log reader" : "Dziennik logów",
    "Open log reader settings" : "Otwórz ustawienia dziennika logów",
    "Log reader settings" : "Ustawienia dziennika logów",
    "Currently the log file {file} is shown" : "Obecnie wyświetlany jest plik dziennika {file}",
    "Show server log" : "Pokaż logi serwera",
    "Live view is disabled" : "Podgląd na żywo jest wyłączony",
    "No log file" : "Brak pliku dziennika",
    "File-based logging must be enabled to access logs from the Web UI." : "Aby uzyskać dostęp do dzienników z internetowego interfejsu użytkownika, należy włączyć rejestrowanie oparte na plikach.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Jeśli uważasz, że to błąd, sprawdź {setting} w swoim {config} i zapoznaj się z instrukcją administracji Nextcloud.",
    "Level" : "Poziom",
    "App" : "Aplikacja",
    "No app in context" : "Brak aplikacji w kontekście",
    "Time" : "Czas",
    "Copy raw entry" : "Kopiuj nieprzetworzony wpis",
    "Copy formatted entry" : "Kopiuj sformatowany wpis",
    "Hide exception details" : "Ukryj szczegóły wyjątku",
    "View exception details" : "Wyświetl szczegóły wyjątku",
    "Raw log entry" : "Nieprzetworzony wpis dziennika",
    "Log entry successfully copied" : "Wpis dziennika został pomyślnie skopiowany",
    "Search log entries" : "Szukaj wpisy dziennika",
    "Caused by {exception}" : "Spowodowane przez {exception}",
    "Line {line}" : "Kolejka {line}",
    "Filter log levels" : "Filtruj poziomy logów",
    "Time format" : "Format czasu",
    "Live view" : "Na żywo",
    "Download/Upload logs" : "Pobierz/prześlij logi",
    "Download logs" : "Pobierz dziennik",
    "Show local log file" : "Pokaż lokalny plik dziennika",
    "Upload local log file to be displayed" : "Wyślij lokalny plik dziennika, który ma zostać wyświetlony",
    "Ctrl" : "Ctrl",
    "Raw data" : "Nieprzetworzone dane",
    "Local time" : "Czas lokalny",
    "UTC time" : "Czas UTC",
    "Relative" : "Pokrewny",
    "Time format used for displaying the timestamp" : "Format czasu używany do wyświetlania znacznika czasu",
    "(Local log files only support the \"raw\" time format)" : "(Lokalne pliki dziennika obsługują tylko \"nieprzetworzony\" format czasu)",
    "Could not change date time format." : "Nie można zmienić formatu daty i godziny.",
    "Polling is disabled because server is not configured to log to file" : "Odpytywanie jest wyłączone, ponieważ serwer nie jest skonfigurowany dla pliku dziennika",
    "Polling (live view)" : "Sonda (podgląd na żywo)",
    "Could not change live view setting." : "Nie można zmienić ustawień podglądu na żywo.",
    "Filter logging levels" : "Filtruj poziomy dziennika",
    "Could not set logging levels to show" : "Nie można ustawić poziomów dziennika do wyświetlenia",
    "Application" : "Aplikacja",
    "Message" : "Komunikat",
    "Log entry actions" : "Akcje z wpisami dziennika",
    "Loading older log entries" : "Wczytywanie starszych wpisów dziennika",
    "No older log entries available" : "Brak dostępnych starszych wpisów dziennika",
    "Collapse row" : "Zwiń wiersz",
    "Expand row" : "Rozwiń wiersz",
    "Show details" : "Pokaż szczegóły",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Nie można wczytać wpisów dziennika",
    "Could not fetch new log entries (server unavailable)" : "Nie można pobrać nowych wpisów dziennika (serwer niedostępny)",
    "Could not fetch new entries" : "Nie udało się pobrać nowych wpisów",
    "Could not copy to clipboard, please copy manually:" : "Nie można skopiować do schowka, skopiuj ręcznie:",
    "\tfrom {address} by {user} at {time}\n" : "\tz {address} przez: {user} o {time}\n",
    "line {line}" : "linia {line}",
    "Download / Upload logs" : "Pobierz/prześlij logi"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
